/*""FILE COMMENT""**************************************************************
*
*       System Name : SH7670 USB Sample Program
*       File Name   : h_debugprint.c
*       Contents    : terminal out for debug
*       Version     : 2.01.00
*       Model       : M3A-HS71
*       CPU         : SH7670
*       Compiler    : SHC9.1.1.0
*       OS          : none
*
*       note        :
*                     <ӎ>
*                     {TvvOׂ͂ĎQlłA
*                     ̓ۏ؂̂ł͂܂B
*                     {TvvO͂ql̃\tgEGAJ
*                     ZpQlƂĂp
*
*       The information described here may contain technical inaccuracies or
*       typographical errors. Renesas Technology Corporation and Renesas Solutions
*       assume no responsibility for any damage, liability, or other loss rising 
*       from these inaccuracies or errors.
*
*       Copyright (C) 2008 Renesas Technology Corp. All Rights Reserved
*       AND Renesas Solutions Corp. All Rights Reserved
*
*       history   : 2008.01.09 ver.1.00.00 
*                 : 2008.01.17 ver.2.00.00 
*                 : 2008.09.02 ver.2.01.00 
*""FILE COMMENT END""*********************************************************/

/******* include file ********************************************************/

#include "..\..\inc\usb_firm.h"
#include "../../../common.h"

static void print_stat_error(USB_U16 Stat);

extern void sci_printf (char* str, ...);

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Get configuration device descriptor end output
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void print_getconf_device_end(USB_U16 Stat)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : USB_U16 Stat			; Status
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void print_getconf_device_end(USB_U16 Stat)
{
#ifdef DEG33
	sci_printf( "Get configuration (Device descriptor) ------------------------\n" );
#endif

	if( Stat == PIPE_DONE ) {
#ifdef DEG33
		sci_printf( " PASS!\n" );
		sci_printf( "    Device descriptor dump :\n" );
		print_put_dmp( UsbDeviceDesc, 18, 4, 16 );
		sci_printf( "\n" );

		/*----- print device descriptor -----*/
		sci_printf( "    Device descriptor fields : \n" );
		sci_printf( "        bLength            : 0x%x\n", UsbDeviceDesc[ 0] );
		sci_printf( "        bDescripotorType   : 0x%x\n", UsbDeviceDesc[ 1] );
		sci_printf( "        bcdUSB             : 0x%d\n", 
				(USB_U16)((USB_U16)UsbDeviceDesc[ 3]*10 + (USB_U16)UsbDeviceDesc[ 2]));
		sci_printf( "        bDeviceClass       : 0x%x\n", UsbDeviceDesc[ 4] );
		sci_printf( "        bDeviceSubClass    : 0x%x\n", UsbDeviceDesc[ 5] );
		sci_printf( "        bProtocolCode      : 0x%x\n", UsbDeviceDesc[ 6] );
		sci_printf( "        bMaxPacketSize     : 0x%x\n", UsbDeviceDesc[ 7] );
		sci_printf( "        idVendor           : 0x%x\n", 
				(USB_U16)((USB_U16)UsbDeviceDesc[ 9]<<8 + (USB_U16)UsbDeviceDesc[ 8]));
		sci_printf( "        idProduct          : 0x%x\n", 
				(USB_U16)((USB_U16)UsbDeviceDesc[11]<<8 + (USB_U16)UsbDeviceDesc[10]));
		sci_printf( "        bcdDevice          : 0x%x\n", 
				(USB_U16)((USB_U16)UsbDeviceDesc[13]<<8 + (USB_U16)UsbDeviceDesc[12]));
		sci_printf( "        iManufacture       : 0x%x\n", UsbDeviceDesc[14] );
		sci_printf( "        iProduct           : 0x%x\n", UsbDeviceDesc[15] );
		sci_printf( "        iSerialNumber      : 0x%x\n", UsbDeviceDesc[16] );
		sci_printf( "        bNumConfigurations : 0x%x\n", UsbDeviceDesc[17] );
		/*----- print device descriptor -----*/
#endif
	} 
	else {
#ifdef DEG33
		print_stat_error(Stat);
#endif
	}
#ifdef DEG33
	sci_printf( "\n" );
#endif
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Get configuration end output
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void print_getconf_config_end(USB_U16 Stat)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : USB_U16 Stat			; Status
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void print_getconf_config_end(USB_U16 Stat)
{
	USB_U16	stat, p, blength, tmp, type;
#ifdef DEG33
	sci_printf( "Get configuration (Configuration descriptor) -----------------\n" );
#endif
	if( Stat == PIPE_DONE ) {
		stat = USB_SUCCESS;

		blength = (USB_U16)((USB_U16)UsbConfigDesc[2] | 
							((USB_U16)UsbConfigDesc[3] << 8));

		for( p = 0; (p < blength) && (stat != USB_ERROR); ) {
			if( UsbConfigDesc[p + 0] == 0 ) {
				type = 0;								/* length == 0 -> error */
				stat = USB_ERROR;						/* exit of infinite loop */
			}
			else {
				type = UsbConfigDesc[p + 1];
			}

			switch( type ) {							/* Descriptor Types */
			case 0:
				/* do nothing */
				break;

			case DT_DEVICE:
#ifdef DEG33
				sci_printf( "    Device descriptor fields:\n" );
#endif
				break;

			case DT_CONFIGURATION:
#ifdef DEG33
				sci_printf( "    Configuration descriptor fields:\n" );
#endif
				tmp = (USB_U16)((USB_U16)UsbConfigDesc[p + 2] | 
								((USB_U16)UsbConfigDesc[p + 3] << 8));
#ifdef DEG33
				sci_printf( "        wTotalLength       : 0x%x\n",tmp );
				sci_printf( "        bNumInterfaces     : 0x%x\n", UsbConfigDesc[p + 4]);
				sci_printf( "        bConfigurationValue: 0x%x\n", UsbConfigDesc[p + 5]);
				sci_printf( "        iConfiguration     : 0x%x\n", UsbConfigDesc[p + 6]);
				sci_printf( "        bmAttributes       : 0x%x\n", UsbConfigDesc[p + 7]);
				sci_printf( "        bMaxPower          : 0x%x\n", UsbConfigDesc[p + 8]);
#endif
				break;

			case DT_STRING:
#ifdef DEG33
				sci_printf( "    String descriptor fields:\n" );
#endif
				break;

			case DT_INTERFACE:
#ifdef DEG33
				sci_printf( "    Interface descriptor fields:\n" );
				sci_printf( "        bInterfaceNumber   : 0x%x\n", UsbConfigDesc[p + 2]);
				sci_printf( "        bAlternateSetting  : 0x%x\n", UsbConfigDesc[p + 3]);
				sci_printf( "        bNumEndpoints      : 0x%x\n", UsbConfigDesc[p + 4]);
				sci_printf( "        bInterfaceClass    : 0x%x\n", UsbConfigDesc[p + 5]);
				sci_printf( "        bInterfaceSubClass : 0x%x\n", UsbConfigDesc[p + 6]);
				sci_printf( "        bInterfaceProtocol : 0x%x\n", UsbConfigDesc[p + 7]);
				sci_printf( "        iInterface         : 0x%x\n", UsbConfigDesc[p + 8]);
#endif			
                        	break;

			case DT_ENDPOINT:
#ifdef DEG33
				sci_printf   ( "    Endpoint descriptor fields:\n" );
#endif
				tmp = (USB_U16)((USB_U16)UsbConfigDesc[p + 4] | 
								((USB_U16)UsbConfigDesc[p + 5] << 8));
				
#ifdef DEG33
                                sci_printf( "        bEndpointAddress   : 0x%x\n", UsbConfigDesc[p + 2] );
				sci_printf( "        bmAttributes       : 0x%x\n", UsbConfigDesc[p + 3] );
				sci_printf( "        wMaxPacketSize     : 0x%x\n", tmp );
				sci_printf( "        bInterval          : 0x%x\n", UsbConfigDesc[p + 6] );
#endif
				break;

			case DT_DEVICE_QUALIFIER:
#ifdef DEG33
				sci_printf   ( "    Device Qualifier descriptor fields:\n" );
#endif
				break;
			case DT_OTHER_SPEED_CONFIGURATION:
#ifdef DEG33
				sci_printf   ( "    Other Speed Configuration descriptor fields:\n" );
#endif
				break;
			case DT_INTERFACE_POWER:
#ifdef DEG33
				sci_printf   ( "    Interface Power descriptor fields:\n" );
#endif
				break;

			default:
#ifdef DEG33
				sci_printf   ( "    \033[41mUnknown fields:\033[0m\n" );
				print_put_dmp( &UsbConfigDesc[p], UsbConfigDesc[p], 4, 16 );
#endif
				break;
			}
			p += UsbConfigDesc[p + 0];
		}
	} 
	else {
#ifdef DEG33
		print_stat_error(Stat);
#endif
	}

#ifdef DEG33
	sci_printf( "\n" );
#endif
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Put error
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: static void print_stat_error(USB_U16 Stat)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : USB_U16 Stat			; Status
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
static void print_stat_error(USB_U16 Stat)
{
	
	switch( Stat ) {
	case PIPE_NORES:
		sci_printf( " ERROR! = NORES\n" );
		break;
	case PIPE_STALL:
		sci_printf( " ERROR! = STALL\n" );
		break;
	default:
		sci_printf( " Stat = %x\n",Stat );
		break;
	}
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Put memory dump
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void print_put_dmp(USB_U8 *Ptr, USB_U8 Size, USB_U16 Spc, USB_U16 Wid)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : USB_U8  *Ptr			; Data Pointer
*            : USB_U16 Size			; Data Size
*            : USB_U16 Spc			; Line Head Space
*            : USB_U16 Wid			; Line Data Count
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void print_put_dmp(USB_U8 *Ptr, USB_U8 Size, USB_U16 Spc, USB_U16 Wid)
{
	USB_U16	i, j, k;

	if( Wid != 0 ) {
		for( i = 0; i < Size;  ) {
			for( k = 0; k < Spc; ++k ){
				sci_printf( "  " );
			}

			for( j = 0; (i < Size) && (j < Wid); ++j, ++i, ++Ptr ) {
				sci_printf( "%02x",*Ptr );
				sci_printf( "  " );
			}
			if( i < Size ){
				sci_printf( "\n" );
			}
		}
	}
	sci_printf( "\n" );
}

/*===========================================================================*/
/* End of File */
