/*""FILE COMMENT""**************************************************************
*
*       System Name : SH7670 USB Sample Program
*       File Name   : h_intrn.c
*       Contents    : Host Pipe Interrupt
*       Version     : 2.01.00
*       Model       : M3A-HS71
*       CPU         : SH7670
*       Compiler    : SHC9.1.1.0
*       OS          : none
*
*       note        :
*                     <ӎ>
*                     {TvvOׂ͂ĎQlłA
*                     ̓ۏ؂̂ł͂܂B
*                     {TvvO͂ql̃\tgEGAJ
*                     ZpQlƂĂp
*
*       The information described here may contain technical inaccuracies or
*       typographical errors. Renesas Technology Corporation and Renesas Solutions
*       assume no responsibility for any damage, liability, or other loss rising 
*       from these inaccuracies or errors.
*
*       Copyright (C) 2008 Renesas Technology Corp. All Rights Reserved
*       AND Renesas Solutions Corp. All Rights Reserved
*
*       history   : 2008.01.09 ver.1.00.00 
*                 : 2008.01.17 ver.2.00.00 
*                 : 2008.09.02 ver.2.01.00 
*""FILE COMMENT END""*********************************************************/

/******* include file ********************************************************/
#include "..\..\inc\usb.h"

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : INTR interrupt
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_BRDYInterrupt(USB_U16 Status, USB_U16 Int_enbl)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : USB_U16 Status		; BRDYSTS Register Value
*            : USB_U16 Int_enbl		; BRDYENB Register Value
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_BRDYInterrupt(USB_U16 Status, USB_U16 Int_enbl)
{
	USB_U16	buffer;

	if( (Status & BITBRDY0) && (Int_enbl & BITBRDY0) ) {
		USB.BRDYSTS.WORD = (USB_U16)~BITBRDY0;
		switch( (UsbCmdStage & (MODE_FIELD | STAGE_FIELD | CMD_FIELD)) )
		{
		case (MODE_WRITE   | STAGE_STATUS | CMD_DOING):
		case (MODE_NO_DATA | STAGE_STATUS | CMD_DOING):
			buffer	= usb_read_buffer_c(PIPE0);
			usb_disable_brdy_int(PIPE0);
			CHG_CMD_FIELD(UsbCmdStage, CMD_DONE);
			break;
		case (MODE_READ   | STAGE_DATA | CMD_DOING):
			buffer	= usb_read_buffer_c(PIPE0);
			switch(buffer) {
			case	READING:					/* Continue of data read */
				break;
			case	READEND:					/* End of data read */
			case	READSHRT:					/* End of data read */
				usb_disable_brdy_int(PIPE0);
				CHG_CMD_FIELD(UsbCmdStage, CMD_DONE);
				break;
			case	READOVER:					/* buffer over */
				USB.CFIFOCTR.WORD = BITBCLR;
				usb_disable_brdy_int(PIPE0);
				CHG_CMD_FIELD(UsbCmdStage, CMD_DONE);
				break;
			case	FIFOERROR:					/* FIFO access error */
			default:
				break;
			}
			break;
		default:
			break;
		}
	} 
	else {
		usb_brdy_int(Status, Int_enbl);
	}
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : INTN interrupt
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_NRDYInterrupt(USB_U16 Status, USB_U16 Int_enbl)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : USB_U16 Status		; NRDYSTS Register Value
*            : USB_U16 Int_enbl		; NRDYENB Register Value
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_NRDYInterrupt(USB_U16 Status, USB_U16 Int_enbl)
{
	USB_U16	pid;

	if( (Status & BITNRDY0) && (Int_enbl & BITNRDY0) ) {
		USB.NRDYSTS.WORD = (USB_U16)~BITNRDY0;

		pid = usb_get_pid(PIPE0);
		if( pid  == PID_STALL ) {
			CHG_CMD_FIELD(UsbCmdStage, CMD_STALL);
		} 
		else if( pid  == PID_NAK ) {
			CHG_CMD_FIELD(UsbCmdStage, CMD_NORES);
		}
	} 
	else {
		usb_nrdy_int(Status, Int_enbl);
	}
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : BEMP interrupt
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_BEMPInterrupt(USB_U16 Status, USB_U16 Int_enbl)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : USB_U16 Status		; BEMPSTS Register Value
*            : USB_U16 Int_enbl		; BEMPENB Register Value
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_BEMPInterrupt(USB_U16 Status, USB_U16 Int_enbl)
{
	USB_U16	buffer, pid;

	if( (Status & BITBEMP0) && (Int_enbl & BITBEMP0) ) {
		USB.BEMPSTS.WORD = (USB_U16)~BITBEMP0;

		pid = usb_get_pid(PIPE0);
		if( pid  == PID_STALL ) {
			CHG_CMD_FIELD(UsbCmdStage, CMD_STALL);
		} 
		else {
			switch( (UsbCmdStage & (MODE_FIELD | STAGE_FIELD | CMD_FIELD)) ) {
			case (MODE_READ | STAGE_STATUS | CMD_DOING):
				CHG_CMD_FIELD(UsbCmdStage, CMD_DONE);
				break;
			case (MODE_WRITE | STAGE_DATA | CMD_DOING):
				buffer	= usb_write_buffer(PIPE0);
				switch(buffer) {
				case	WRITING:					/* Continue of data write */
				case	WRITEEND:					/* End of data write (zero-length) */
					break;
				case	WRITESHRT:					/* End of data write */
					CHG_STAGE_FIELD(UsbCmdStage, STAGE_STATUS);
					break;
				case	FIFOERROR:					/* FIFO access error */
				default:
					break;
				}
				break;
			case (MODE_WRITE | STAGE_STATUS | CMD_DOING):
				CHG_CMD_FIELD(UsbCmdStage, CMD_IDLE);
				break;
			default:
				/* do nothing */
				break;
			}
		}
	} 
	else {
		usb_bemp_int(Status, Int_enbl);
	}
}

/*===========================================================================*/
/* End of File */
