/*""FILE COMMENT""**************************************************************
*
*       System Name : SH7670 USB Sample Program
*       File Name   : h_lib7265.c
*       Contents    : Host SH7265 USB Register
*       Version     : 2.01.00
*       Model       : M3A-HS71
*       CPU         : SH7670
*       Compiler    : SHC9.1.1.0
*       OS          : none
*
*       note        :
*                     <ӎ>
*                     {TvvOׂ͂ĎQlłA
*                     ̓ۏ؂̂ł͂܂B
*                     {TvvO͂ql̃\tgEGAJ
*                     ZpQlƂĂp
*
*       The information described here may contain technical inaccuracies or
*       typographical errors. Renesas Technology Corporation and Renesas Solutions
*       assume no responsibility for any damage, liability, or other loss rising 
*       from these inaccuracies or errors.
*
*       Copyright (C) 2008 Renesas Technology Corp. All Rights Reserved
*       AND Renesas Solutions Corp. All Rights Reserved
*
*       history   : 2008.01.09 ver.1.00.00 
*                 : 2008.01.17 ver.2.00.00 
*                 : 2008.09.02 ver.2.01.00 
*""FILE COMMENT END""*********************************************************/

/******* include file ********************************************************/
#include "..\..\inc\usb.h"
#include "../../../common.h"

extern void sci_printf (char* str, ...);

extern int  BULK_OUT_PIPE;
extern int  BULK_IN_PIPE;

/*""FUNC COMMENT""*************************************************************
* ID          : 
* Outline     : Set pipe information
*-----------------------------------------------------------------------------
* Include     : 
*-----------------------------------------------------------------------------
* Declaration : USB_U16 H_SetEndpointTable( USB_CFG_PIPETBL *user_table,
*             :                             USB_U8* Table );
*-----------------------------------------------------------------------------
* Function    : 
*-----------------------------------------------------------------------------
* Argument    : USB_CFG_PIPETBL *user_table   : pipe table
*             : USB_U8* Table                 : Endpoint descriptor
*-----------------------------------------------------------------------------
* ReturnValue : DIR_H_IN           : IN endpoint
*             : DIR_H_OUT          : OUT endpoint
*             : 0xFFFF             : error
*-----------------------------------------------------------------------------
* Note        : 
*""FUNC COMMENT END""********************************************************/
USB_U16		H_SetEndpointTable( USB_CFG_PIPETBL *user_table, USB_U8* Table)
{
	USB_U16		PipeCfg, PipeMaxp;
	USB_U16		pipe_number;
	USB_U16		ret;

	pipe_number	= user_table->pipe_number;

	if( Table[ 1 ] != DT_ENDPOINT ){
		return	0xFFFF;
	}



	switch(Table[ 3 ] & EP_TYPE){
	case	EP_CNTRL:
		return	0xFFFF;
		break;

	case	EP_ISO:
		if( (pipe_number != PIPE1) && (pipe_number != PIPE2) ){
			return	0xFFFF;
		}

		PipeCfg	= ISO;
		break;

	case	EP_BULK:
		if( (pipe_number < PIPE1) || (pipe_number > PIPE5) ){
			return	0xFFFF;
		}

		PipeCfg	= BULK;
		break;

	case	EP_INT:				/* Interrupt Endpoint 	*/
		if( (pipe_number < PIPE6) || (pipe_number > PIPE9) ){
			return	0xFFFF;
		}

		PipeCfg	= INT;
		break;

	default:
		return	0xFFFF;
		break;
	}

	/* Set pipe configuration table */
	if ((Table[ 2 ] & EP_DIR_MASK) == EP_IN){				/* IN(receive) */

		PipeCfg	|= (SHTNAKON | DIR_H_IN);					/* Compulsory SHTNAK */
		switch(user_table->fifo_port) {
		case	CUSE:		/* Prohibition DBLB / CNTMD 	*/
			PipeCfg	|=  (USB_U16)(user_table->pipe_cfg & (DBLBOFF   | CNTMDOFF));
			break;

		case	D0USE:
		case	D1USE:
			PipeCfg	|=  (USB_U16)(user_table->pipe_cfg & (DBLBFIELD | CNTMDFIELD));
			break;

		case	D0DMA:
		case	D1DMA:
		#if	0
			PipeCfg	|= (USB_U16)((user_table->pipe_cfg & 
										(DBLBFIELD | CNTMDFIELD)) | BFREON);
		#else
			PipeCfg	|= (USB_U16)((user_table->pipe_cfg & 
										(DBLBFIELD | CNTMDFIELD)));
		#endif
			break;

		default:
			return	0xFFFF;
			break;
		}

		ret = DIR_H_IN;
	}
	else{				/* OUT(send) 	*/
		PipeCfg	|= (USB_U16)((user_table->pipe_cfg & 
										(DBLBFIELD | CNTMDFIELD)) | DIR_H_OUT);
		ret = DIR_H_OUT;
	}

	switch(user_table->fifo_port) {
	case	CUSE:
		PipeTbl[ pipe_number ] = (USB_U16)C_FIFO_USE;
		break;

	case	D0USE:
		PipeTbl[ pipe_number ] = (USB_U16)D0_FIFO_USE;
		break;
	case	D1USE:
		PipeTbl[ pipe_number ] = (USB_U16)D1_FIFO_USE;
		break;
	case	D0DMA:
		PipeTbl[ pipe_number ] = (USB_U16)D0_FIFO_DMA;
		break;
	case	D1DMA:
		PipeTbl[ pipe_number ] = (USB_U16)D1_FIFO_DMA;
		break;

	default:
		return	0xFFFF;
		break;
	}

	/* Endpoint number set 				*/
	PipeCfg  |= (USB_U16)(Table[ 2 ] & EP_NUM_MASK);
	PipeTbl[ pipe_number ] |= (USB_U16)(Table[ 2 ] & EP_NUM_MASK);

	/* Max packet size set 				*/
	PipeMaxp  = (USB_U16)((USB_U16)Table[ 4 ] | (USB_U16)((USB_U16)Table[ 5 ] << 8));

	/* Set device address 				*/
	PipeMaxp |= ( USB_U16 )( UsbAddress << 12 );

	user_table->pipe_cfg			= PipeCfg;
	user_table->pipe_max_pktsize	= PipeMaxp;


#ifdef DEG35
        /* added */
        sci_printf( "---- in H_SetEndpointTable \n" );
        sci_printf( "     pipe number = %d  \n", pipe_number);

        if( (PipeCfg & BULK) == BULK)      sci_printf( "     BULK \n");
        else sci_printf( "     Not BULK \n");

        switch(ret)
        {
           case DIR_H_IN:
              sci_printf( "     DIR_H_IN \n");
              break;
           case DIR_H_OUT:
              sci_printf( "     DIR_H_OUT \n");
              break;
           default:
              sci_printf( "     DIR is unknown\n");
        }

        sci_printf( "     PipeTbl = 0x%x \n", PipeTbl[ pipe_number ]  );
        sci_printf( "     device addres/max packet size = %d \n", PipeMaxp );
#endif

       if( ret == DIR_H_IN)  BULK_IN_PIPE = pipe_number;
       else if( ret == DIR_H_OUT) BULK_OUT_PIPE = pipe_number;

#ifdef DEG35
      sci_printf( "BULK_OUT_PIPE = %d,  BULK_IN_PIPE= %d \n", BULK_OUT_PIPE, BULK_IN_PIPE);
#endif

        /**  **/

	H_resetEP( user_table );

	return ret;
}

/*""FUNC COMMENT""*************************************************************
* ID          : 
* Outline     : End point pipe setting
*-----------------------------------------------------------------------------
* Include     : 
*-----------------------------------------------------------------------------
* Declaration : void H_resetEP( USB_CFG_PIPETBL *tbl);
*-----------------------------------------------------------------------------
* Function    : 
*-----------------------------------------------------------------------------
* Argument    : USB_CFG_PIPETBL *tbl : pipe table
*-----------------------------------------------------------------------------
* ReturnValue : void
*-----------------------------------------------------------------------------
* Note        : 
*""FUNC COMMENT END""********************************************************/
void	H_resetEP( USB_CFG_PIPETBL *tbl)
{

	USB_U16		pipe;

	/* Host pipe */
	/* The pipe number of pipe definition table is obtained */
	pipe = ( USB_U16 )( tbl->pipe_number & BITCURPIPE );	/* Pipe Number */

	/* FIFO port access pipe is set to initial value */
	/* The connection with FIFO should be cut before setting the pipe */
	if( USB.CFIFOSEL.BIT.CURPIPE == pipe ){
		usb_change_fifo_port( PIPE0,CUSE,USB_NO, BITMBW_16 );
	}
	if( USB.D0FIFOSEL.BIT.CURPIPE == pipe ){
		usb_change_fifo_port( PIPE0,D0USE,USB_NO, BITMBW_16 );
	}
	if( USB.D1FIFOSEL.BIT.CURPIPE == pipe ){
		usb_change_fifo_port( PIPE0,D1USE,USB_NO, BITMBW_16 );
	}

	/* Interrupt of pipe set is disabled */
	usb_disable_brdy_int(pipe);
	usb_disable_nrdy_int(pipe);
	usb_disable_bemp_int(pipe);

	/* Pipe to set is set to NAK */
	usb_set_pid_nak(pipe);

	/* Pipe is set */
	USB.PIPESEL.WORD = pipe;

	USB.PIPECFG.WORD = tbl->pipe_cfg;
	USB.PIPEBUF.WORD = tbl->pipe_buf;
	USB.PIPEMAXP.WORD = tbl->pipe_max_pktsize;
	USB.PIPEPERI.WORD = tbl->pipe_cycle;
	
	/* Sequence bit clear */
	usb_set_sqclr(pipe);
	UsbSqbit[ pipe ] = 0;

	usb_aclrm(pipe);
	usb_set_csclr(pipe);

	/* Pipe window selection is set to unused */
	USB.PIPESEL.WORD = PIPE0;

}

/*===========================================================================*/
/* End of File */
