/*""FILE COMMENT""**************************************************************
*
*       System Name : SH7670 USB Sample Program
*       File Name   : h_usbdrv.c
*       Contents    : Host USB Class Driver
*       Version     : 2.01.00
*       Model       : M3A-HS71
*       CPU         : SH7670
*       Compiler    : SHC9.1.1.0
*       OS          : none
*
*       note        :
*                     <ӎ>
*                     {TvvOׂ͂ĎQlłA
*                     ̓ۏ؂̂ł͂܂B
*                     {TvvO͂ql̃\tgEGAJ
*                     ZpQlƂĂp
*
*       The information described here may contain technical inaccuracies or
*       typographical errors. Renesas Technology Corporation and Renesas Solutions
*       assume no responsibility for any damage, liability, or other loss rising 
*       from these inaccuracies or errors.
*
*       Copyright (C) 2008 Renesas Technology Corp. All Rights Reserved
*       AND Renesas Solutions Corp. All Rights Reserved
*
*       history   : 2008.01.09 ver.1.00.00 
*                 : 2008.01.17 ver.2.00.00 
*                 : 2008.09.02 ver.2.01.00 
*""FILE COMMENT END""*********************************************************/

/******* include file ********************************************************/
#include "..\..\inc\usb.h"
#include "../../../common.h"

extern void sci_printf (char* str, ...);

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB driver
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_UsbStateManager(void);
*----------------------------------------------------------------------------- 
* Function   : Enumeration & Detach check
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_UsbStateManager( void )
{
	USB_S16						ret_s;
	USB_U16						stat;
	USB_U16						confsize;
	USB_U16						conect;
	DEVADD						devadd;
	extern  USB_CFG_PIPETBL     VendorDefEPTbl0[];

	if( UsbDeviceState == DVST_CONFIGURED ){
		return;
	}

	switch( UsbDeviceState )
	{
	case DVST_DETACHED:
		if( UsbAtchFlg == USB_YES ) {
			UsbAtchFlg = USB_NO;
			conect = H_CheckAttach();
			if( conect == ATTACH ) {
				UsbDeviceState = DVST_ATTACHED;
			} 
			else {
				H_UsbDetach();
			}
		}
		break;

	case DVST_ATTACHED:								/* Attach 	*/
		H_UsbAttach();
		stat = H_UsbBusReset();
		if(stat != UNDECID){
			if( stat == HSMODE ){
				UsbDeviceSpeed = HI_SPEED;
			}
			else if( stat == FSMODE ){
				UsbDeviceSpeed = FULL_SPEED;
			}
			else{
				UsbDeviceSpeed = LOW_SPEED;
			}

			/* DEVADD register setting */
			devadd.BIT.UPPHUB = 0;
			devadd.BIT.HUBPORT = 0;
			if( stat == HSMODE ){
				UsbDeviceSpeed 	= HI_SPEED;
				devadd.BIT.USBSPD 	= USBSPD_HI;
			}
			else if( stat == FSMODE ){
				UsbDeviceSpeed 	= FULL_SPEED;
				devadd.BIT.USBSPD 	= USBSPD_FUL;
			}
			else{
				UsbDeviceSpeed 	= LOW_SPEED;
				devadd.BIT.USBSPD 	= USBSPD_LOW;
			}

			UsbAddress = DEVICE_0 ;
			UsbMaxPacketSize = 64;
			usb_init_mem();

			/* Default device registlation */
			usb_set_devadd( DEVICE_0, &devadd );

			UsbDeviceState = DVST_GET_DESCRIPTOR_64;	/* DONE */
		} 
		else {
			UsbDeviceState = DVST_NORES;				/* ERROR 	*/
			UsbDeviceSpeed = NON_SPEED;
		}
		break;

	case DVST_GET_DESCRIPTOR_64:					/* DEVICE descriptor 64byte */
		H_CtrlTransStart( 0x0680, 0x0100, 0x0000, 64, (USB_U8 *)UsbDeviceDesc);
		if( PipeFlag[ PIPE0 ] != PIPE_WAIT ){
			switch( PipeFlag[PIPE0] ) {
			case PIPE_DONE:
				UsbMaxPacketSize  = (USB_U16)UsbDeviceDesc[ 7 ];

				PipeFlag[ PIPE0 ] = PIPE_IDLE;
				UsbDeviceState    = DVST_POWERED;
				break;
			case PIPE_NORES:
				UsbDeviceState    = DVST_NORES;			/* ERROR */
				break;
			case PIPE_STALL:
				UsbDeviceState    = DVST_STALL;			/* ERROR */
				break;
			}
		}
		break;

	case DVST_POWERED:								/* Bus Reset */
		stat = H_UsbBusReset();
		if( stat == HSMODE || stat == FSMODE || stat == LSMODE ) {
			UsbDeviceState = DVST_DEFAULT;			/* DONE */
		} 
		else {
			UsbDeviceState = DVST_NORES;			/* ERROR */
		}
		break;

	case DVST_DEFAULT:
		PipeFlag[PIPE0] = PIPE_IDLE;
		UsbDeviceState = DVST_SET_ADDRESS;
		break;

	case DVST_SET_ADDRESS:							/* Address USB_ADR */
		H_CtrlTransStart( 0x0500, USB_ADR, 0x0000, 0x0000, (USB_U8 *)0);
		if( PipeFlag[ PIPE0 ] != PIPE_WAIT ){
			switch( PipeFlag[PIPE0] ) {
			case PIPE_DONE:
				UsbAddress = USB_ADR ;		/* Set Address */

				PipeFlag[ PIPE0 ] = PIPE_IDLE;
				UsbDeviceState    = DVST_ADDRESS;
				break;
			case PIPE_NORES:
				UsbDeviceState = DVST_NORES;		/* ERROR */
				break;
			case PIPE_STALL:
				UsbDeviceState = DVST_STALL;		/* ERROR */
				break;
			}
		}
		break;

	case DVST_ADDRESS:

		usb_get_devadd( DEVICE_0, &devadd );

		usb_set_devadd( UsbAddress, &devadd );

		PipeFlag[PIPE0] = PIPE_IDLE;
		UsbDeviceState  = DVST_GET_DESCRIPTOR_18;
		break;

	case DVST_GET_DESCRIPTOR_18:					/* DEVICE descriptor 18byte */
		H_CtrlTransStart( 0x0680, 0x0100, 0x0000, 18, (USB_U8 *)UsbDeviceDesc);
		if( PipeFlag[ PIPE0 ] != PIPE_WAIT ){
			switch( PipeFlag[PIPE0] ) {
			case PIPE_DONE:
				PipeFlag[PIPE0] = PIPE_IDLE;
				UsbDeviceState  = DVST_GET_DESCRIPTOR_9;
				break;
			case PIPE_NORES:
				UsbDeviceState  = DVST_NORES;			/* ERROR */
				break;
			case PIPE_STALL:
				UsbDeviceState  = DVST_STALL;			/* ERROR */
				break;
			}
		}
		break;

	case DVST_GET_DESCRIPTOR_9:						/* CONFIGURATION descriptor 9byte */
		H_CtrlTransStart( 0x0680, 0x0200, 0x0000, 9, (USB_U8 *)UsbConfigDesc);
		if( PipeFlag[ PIPE0 ] != PIPE_WAIT ){
			switch( PipeFlag[PIPE0] ) {
			case PIPE_DONE:
				PipeFlag[PIPE0] = PIPE_IDLE;
				UsbDeviceState  = DVST_GET_DESCRIPTOR_SIZE;
				break;
			case PIPE_NORES:
				UsbDeviceState = DVST_NORES;			/* ERROR */
				break;
			case PIPE_STALL:
				UsbDeviceState = DVST_STALL;			/* ERROR */
				break;
			}
		}
		break;

	case DVST_GET_DESCRIPTOR_SIZE:
		/* Descriptor Total Length */
		confsize = (USB_U16)((USB_U16)UsbConfigDesc[2] 
								| ((USB_U16)UsbConfigDesc[3] << 8));
		/* CONFIGURATION descriptor (Max:255byte) */
		if( confsize < 256 ) {
			H_CtrlTransStart( 0x0680, 0x0200, 0x0000, confsize, 
												(USB_U8 *)UsbConfigDesc);
		} 
		else {
			H_CtrlTransStart( 0x0680, 0x0200, 0x0000, 255,
												 (USB_U8 *)UsbConfigDesc);
		}

		if( PipeFlag[ PIPE0 ] != PIPE_WAIT ){
			switch( PipeFlag[PIPE0] ) {
			case PIPE_DONE:
				PipeFlag[PIPE0] = PIPE_IDLE;
				UsbDeviceState  = DVST_SET_PIPE;
				break;
			case PIPE_NORES:
				UsbDeviceState  = DVST_NORES;			/* ERROR */
				break;
			case PIPE_STALL:
				UsbDeviceState  = DVST_STALL;			/* ERROR */
				break;
			}
		}
		break;

	case DVST_SET_PIPE:
		ConfigNum = (USB_U16)UsbConfigDesc[ 5 ];
		PipeFlag[PIPE0] = PIPE_IDLE;
		UsbDeviceState  = DVST_SET_CONFIGURATION;
		break;

	case DVST_SET_CONFIGURATION:					/* Configuration ConfigNum */
		H_CtrlTransStart( 0x0900, ConfigNum, 0x0000, 0x0000, (USB_U8 *)0);
		if( PipeFlag[ PIPE0 ] != PIPE_WAIT ){
			switch( PipeFlag[PIPE0] ) {
			case PIPE_DONE:
				PipeFlag[PIPE0] = PIPE_IDLE;
				UsbDeviceState = DVST_CONFIGURED;

				ret_s = H_SetEndpoint( (USB_U8 *)&UsbConfigDesc[ 0 ],
										&VendorDefEPTbl0[ 0 ] );
				if( ret_s != USB_SUCCESS ){
				#if	0
					PipeFlag[PIPE0] = PIPE_STALL;
					/* G[̏ꍇAUSBfoCXɍ킹ăpCv`e[u	*/
					/* ݒ肵ĂB										*/
				#endif
				}
                                else
                                {
#ifdef DEG32
                                 sci_printf( " H_SetEndpoint sucess, PIPE0= %d, in h_usbdrv \n", PIPE0 );
#endif 
                               }

				break;
			case PIPE_NORES:
				UsbDeviceState = DVST_NORES;			/* ERROR */
				break;
			case PIPE_STALL:
				UsbDeviceState = DVST_STALL;			/* ERROR */
				break;
			}
		}
		break;

	case DVST_NORES:
		H_UsbDetach();
		break;

	case DVST_STALL:
		/* nothing */
		break;
	default:
		break;
	}
}

/*===========================================================================*/
/* End of File */
