/*""FILE COMMENT""**************************************************************
*
*       System Name : SH7670 USB Sample Program
*       File Name   : h_usbdrv_api.c
*       Contents    : Host USB Class Driver
*       Version     : 2.01.00
*       Model       : M3A-HS71
*       CPU         : SH7670
*       Compiler    : SHC9.1.1.0
*       OS          : none
*
*       note        :
*                     <ӎ>
*                     {TvvOׂ͂ĎQlłA
*                     ̓ۏ؂̂ł͂܂B
*                     {TvvO͂ql̃\tgEGAJ
*                     ZpQlƂĂp
*
*       The information described here may contain technical inaccuracies or
*       typographical errors. Renesas Technology Corporation and Renesas Solutions
*       assume no responsibility for any damage, liability, or other loss rising 
*       from these inaccuracies or errors.
*
*       Copyright (C) 2008 Renesas Technology Corp. All Rights Reserved
*       AND Renesas Solutions Corp. All Rights Reserved
*
*       history   : 2008.01.09 ver.1.00.00 
*                 : 2008.01.17 ver.2.00.00 
*                 : 2008.09.02 ver.2.01.00 
*""FILE COMMENT END""*********************************************************/

/******* include file ********************************************************/
#include "..\..\inc\usb.h"

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Electorical test mode initialize
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_EL_ModeInit(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_EL_ModeInit( void )
{
	H_ModeInit();
	H_CheckAttach();
	H_UsbAttach();
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Electorical test BUS reset
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_EL_UsbBusReset( void )
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_EL_UsbBusReset( void )
{
	USB_U16		stat;
	DEVADD		devadd;

	stat = H_UsbBusReset();
	if( stat != UNDECID  ) {
			/* Enable Detach Detect		*/
			H_Enable_DetachINT();
			if( stat == HSMODE ){
				UsbDeviceSpeed = HI_SPEED;
			}
			else if( stat == FSMODE ){
				UsbDeviceSpeed = FULL_SPEED;
			}
			else{
				UsbDeviceSpeed = LOW_SPEED;
			}

			/* DEVADD register setting */
			devadd.BIT.UPPHUB = 0;
			devadd.BIT.HUBPORT = 0;
			if( stat == HSMODE ){
				UsbDeviceSpeed 	= HI_SPEED;
				devadd.BIT.USBSPD 	= USBSPD_HI;
			}
			else if( stat == FSMODE ){
				UsbDeviceSpeed 	= FULL_SPEED;
				devadd.BIT.USBSPD 	= USBSPD_FUL;
			}
			else{
				UsbDeviceSpeed 	= LOW_SPEED;
				devadd.BIT.USBSPD 	= USBSPD_LOW;
			}

			/* Default device registlation */
			usb_set_devadd( DEVICE_0, &devadd );
	}
	else{
		/* Disable Detach Detect*/
		H_Disable_DetachINT();
	}
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Electorical test device attach
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_EL_UsbAttach(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_EL_UsbAttach( void )
{
	H_CheckAttach();
	H_UsbAttach();
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Setup stage
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_EL_SetupStage(USB_U16 Req, USB_U16 Val, USB_U16 Indx, USB_U16 Len);
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : USB_U16 Req			; bmRequestType & bRequest
*            : USB_U16 Val			; wValue
*            : USB_U16 Indx			; wIndex
*            : USB_U16 Len			; wLength
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_EL_SetupStage( USB_U16 Req, USB_U16 Val, USB_U16 Indx, USB_U16 Len)
{
	H_SetupStage( Req, Val, Indx, Len );
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Status stage
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_EL_StatusStage(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_EL_StatusStage( void )
{
	H_StatusStage();
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Control write start
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: USB_U16 H_EL_CtrlWriteStart(USB_U32 Bsize, USB_U8 *Table)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : USB_U32 Bsize		; Data Size
*            : USB_U8  *Table		; Data Table Address
*----------------------------------------------------------------------------- 
* ReturnValue: WRITESHRT	;	End of data write
*            : WRITEEND		;	End of data write (not null)
*            : WRITING		;	Continue of data write
*            : FIFOERROR	;	FIFO access error
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
USB_U16 H_EL_CtrlWriteStart( USB_U32 Bsize, USB_U8 *Table)
{
	USB_U16		EndFlag_K;

	EndFlag_K = H_CtrlWriteStart( Bsize, Table );

	return EndFlag_K;
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Control read start
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_EL_CtrlReadStart(USB_U32 Bsize, USB_U8 *Table)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : USB_U32 Bsize		; Data Size
*            : USB_U8  *Table		; Data Table Address
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_EL_CtrlReadStart( USB_U32 Bsize, USB_U8 *Table)
{
	H_CtrlReadStart( Bsize, Table );
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB resume
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: USB_U16 H_EL_UsbResume(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: USB_U16				; SUCCESS
*            :                      ; ERROR
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
USB_U16 H_EL_UsbResume( void )
{
	USB_U16		ret;

	ret = H_UsbResume();

	return ret;
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB suspend
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: USB_U16 H_EL_UsbSuspend(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: USB_U16				; SUCCESS :not SUSPEND
*            :                      ; ERROR   :SUSPEND
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
USB_U16 H_EL_UsbSuspend( void )
{
	USB_U16		ret;

	ret = H_UsbSuspend();

	return ret;
}

/*===========================================================================*/
/* End of File */
