/*""FILE COMMENT""**************************************************************
*
*       System Name : SH7670 USB Sample Program
*       File Name   : h_usbsig.c
*       Contents    : Host USB Bus Driver
*       Version     : 2.01.00
*       Model       : M3A-HS71
*       CPU         : SH7670
*       Compiler    : SHC9.1.1.0
*       OS          : none
*
*       note        :
*                     <ӎ>
*                     {TvvOׂ͂ĎQlłA
*                     ̓ۏ؂̂ł͂܂B
*                     {TvvO͂ql̃\tgEGAJ
*                     ZpQlƂĂp
*
*       The information described here may contain technical inaccuracies or
*       typographical errors. Renesas Technology Corporation and Renesas Solutions
*       assume no responsibility for any damage, liability, or other loss rising 
*       from these inaccuracies or errors.
*
*       Copyright (C) 2008 Renesas Technology Corp. All Rights Reserved
*       AND Renesas Solutions Corp. All Rights Reserved
*
*       history   : 2008.01.09 ver.1.00.00 
*                 : 2008.01.17 ver.2.00.00 
*                 : 2008.09.02 ver.2.01.00 
*""FILE COMMENT END""*********************************************************/

/******* include file ********************************************************/
#include "..\..\inc\usb.h"

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Initialize USB Module
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_InitModule(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_InitModule(void)
{
	USB_U16	buf1, buf2, buf3;

	usb_init_mem();

	USB.SYSCFG.BIT.DCFM = 1;		/* HOST mode 	*/

	USB.SYSCFG.BIT.DRPD = 1;		/* PORT0 D+, D- setting */

	do {
		buf1 = USB.SYSSTS.BIT.LNST;
		usb_delay_xms( 50 );
		buf2 = USB.SYSSTS.BIT.LNST;
		usb_delay_xms( 50 );
		buf3 = USB.SYSSTS.BIT.LNST;

	} while( ( buf1 != buf2 ) || ( buf1 != buf3 ) );

	/* USB clock operation enabled */
	USB.SYSCFG.BIT.USBE = 1;

	/* xFIFOSEL initialization */
	USB.CFIFOSEL.WORD =  ( USB_U16 )( BITRCNT | BITMBW_16 | BITBYTE_BIG );
	USB.D0FIFOSEL.WORD = ( USB_U16 )(           BITMBW_16 | BITBYTE_BIG );
	USB.D1FIFOSEL.WORD = ( USB_U16 )(           BITMBW_16 | BITBYTE_BIG );

}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : Check Atacch
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: USB_U16 H_CheckAttach(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: USB_U16				; USB_YES : Attached
*            :                      ; NO  : not Attached
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
USB_U16 H_CheckAttach(void)
{
	USB_U16	buf1, buf2, buf3;
	USB_U16	rhst;

	do {
		buf1 = USB.SYSSTS.BIT.LNST;
		usb_delay_xms( 50 );
		buf2 = USB.SYSSTS.BIT.LNST;
		usb_delay_xms( 50 );
		buf3 = USB.SYSSTS.BIT.LNST;

	} while( ( buf1 != buf2 ) || ( buf1 != buf3 ) );
	rhst = USB.DVSTCTR.BIT.RHST;
	if( rhst == UNDECID ){
		if( buf1 == FS_JSTS ) {
				USB.SYSCFG.BIT.HSE = 1;				/* HSE = enable */
			return ATTACH;
		} 
		else if( buf1 == LS_JSTS ) {
			/* Low Speed Device */
			USB.SYSCFG.BIT.HSE = 0;				/* HSE = enable */
			return ATTACH;
		}
	}
	else if( ( rhst == HSMODE ) || ( rhst == FSMODE ) ){
		return ATTACH;
	}
	else if( rhst == LSMODE ){
		return ATTACH;
	}
	return DETACH;
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB attach
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_UsbAttach(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_UsbAttach(void)
{
	H_EnableINT_Module();						/* Interrupt Enable */

	H_Disable_BchgINT();
	H_Disable_AttachINT();
	H_Enable_DetachINT();

	/* FIFO Clear, etc ... */
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB detach
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_UsbDetach(void);
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_UsbDetach(void)
{
	USB_U16 pipe;
	USB_U16	devadr;
	extern  USB_CFG_PIPETBL     VendorDefEPTbl0[];

	UsbDeviceState = DVST_DETACHED;

	/* Terminate all the pipes in which communications on port 	*/
	/* are currently carried out 								*/
	for( pipe = 0; pipe < (MAX_PIPE_NO + 1); ++pipe ) {
		if( PipeFlag[ pipe ] != PIPE_IDLE ){
			if(pipe == PIPE0){
				devadr = USB.DCPMAXP.BIT.DEVSEL;
			}
			else{
				/* Pipe is set */
				USB.PIPESEL.WORD = pipe;

				devadr = USB.PIPEMAXP.BIT.DEVSEL;
			}
			if( devadr == UsbAddress ){ 
				usb_stop_transfer( pipe );
				PipeFlag[ pipe ] = PIPE_IDLE;
			}
		}
	}

	H_ClrEndpoint(&VendorDefEPTbl0[ 0 ] );

	ConfigNum	= 0;
	UsbAddress = 0;
	UsbMaxPacketSize = 64;						/* 64byte 		*/

	/* DTCH interrupt disable */
	H_Disable_DetachINT();
	H_Disable_BchgINT();

	H_Enable_AttachINT();
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB bus reset
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: USB_U16 H_UsbBusReset(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: USB_U16				; RHST
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
USB_U16 H_UsbBusReset(void)
{
	USB_U16	buffer, i;

	/* USB RESET */
	USB.DVSTCTR.BIT.USBRST = 1;			/* USB Bus Reset Enable 		*/
	USB.DVSTCTR.BIT.UACT   = 0;
	usb_delay_xms( 50 );				/* 50ms wait 					*/

	/* SOF ON */
	USB.DVSTCTR.BIT.UACT   = 1;			/* SOF out enable 				*/
	USB.DVSTCTR.BIT.USBRST = 0;
	usb_delay_xms( 20 );				/* 20ms USB reset recovery 		*/

	for( i = 0, buffer = HSPROC;  i < 3; ++i ) {
		buffer = USB.DVSTCTR.BIT.RHST;
		if( buffer == HSPROC ) {
			usb_delay_xms( 10 );		/* wait */
		}
		else{
			break;
		}
	}
	return(buffer);
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB resume
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: USB_U16 H_UsbResume(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: USB_U16				; SUCCESS
*            :                      ; ERROR
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
USB_U16 H_UsbResume( void )
{
	USB_U16		buf;

	if( (UsbDeviceState & DVST_SUSPEND) == 0 ) {	/* not SUSPEND */
		return (USB_U16)USB_ERROR;
	}

	USB.INTENB1.BIT.BCHGE  = 0;
	USB.DVSTCTR.BIT.RESUME = 1;			/* RESUME bit on 	*/
	usb_delay_xms( 20 );					/* wait 			*/

	buf  = USB.DVSTCTR.WORD;
	buf &= ( USB_U16 )( ~( BITRESUME ) );
	buf |= BITUACT;
	USB.DVSTCTR.WORD = buf;

	UsbDeviceState &= (USB_U16)~DVST_SUSPEND;		/* bit off */

	return USB_SUCCESS;
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB suspend
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: USB_U16 H_UsbSuspend(void)
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: USB_U16				; SUCCESS :not SUSPEND
*            :                      ; ERROR   :SUSPEND
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
USB_U16 H_UsbSuspend(void)
{
	USB_U16	buf;

	if( (UsbDeviceState & DVST_SUSPEND) != 0 ) {	/* SUSPEND */
		return (USB_U16)USB_ERROR;
	}

	USB.DVSTCTR.BIT.UACT = 0;					/* SOF OFF */

	usb_delay_xms((USB_U16)5);							/* wait */

	buf = USB.SYSSTS.BIT.LNST;
	if( ( buf != FS_JSTS ) && ( buf != LS_JSTS ) ) {
		H_UsbDetach();								/* DETACH */
	} 
	else {
		UsbDeviceState |= DVST_SUSPEND;				/* SUSPEND */
	}

	return (USB_U16)USB_SUCCESS;
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB detach enable
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_Enable_DetachINT(void);
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_Enable_DetachINT( void )
{
	USB.INTSTS1.WORD      = ( USB_U16 )( ~( BITDTCH ) );
	USB.INTENB1.BIT.DTCHE = 1;
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB detach disable
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_Disable_DetachINT(void);
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_Disable_DetachINT( void )
{
	USB.INTSTS1.WORD      = ( USB_U16 )( ~( BITDTCH ) );
	USB.INTENB1.BIT.DTCHE = 0;
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB detach enable
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_Enable_DetachINT(void);
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_Enable_AttachINT( void )
{
	USB.INTSTS1.WORD      = ( USB_U16 )( ~( BITATTCH ) );
	USB.INTENB1.BIT.ATTCHE = 1;
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB detach disable
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_Disable_DetachINT(void);
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_Disable_AttachINT( void )
{
	USB.INTSTS1.WORD      = ( USB_U16 )( ~( BITATTCH ) );
	USB.INTENB1.BIT.ATTCHE = 0;
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB detach enable
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_Enable_DetachINT(void);
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_Enable_BchgINT( void )
{
	USB.INTSTS1.WORD      = ( USB_U16 )( ~( BITBCHG ) );
	USB.INTENB1.BIT.BCHGE = 1;
}

/*""FUNC COMMENT""************************************************************ 
* ID         : 
* Outline    : USB detach disable
*----------------------------------------------------------------------------- 
* Include    : 
*----------------------------------------------------------------------------- 
* Declaration: void H_Disable_DetachINT(void);
*----------------------------------------------------------------------------- 
* Function   : 
*            : 
*----------------------------------------------------------------------------- 
* Argument   : void
*----------------------------------------------------------------------------- 
* ReturnValue: void
*----------------------------------------------------------------------------- 
* Notice     : 
*            : 
*""FUNC COMMENT END""*********************************************************/
void H_Disable_BchgINT( void )
{
	USB.INTSTS1.WORD      = ( USB_U16 )( ~( BITBCHG ) );
	USB.INTENB1.BIT.BCHGE = 0;
}

/*""FUNC COMMENT""*************************************************************
* ID          : 
* Outline     : DEVADDn register setting 
*-----------------------------------------------------------------------------
* Include     : 
*-----------------------------------------------------------------------------
* Declaration : void usb_set_devadd( USB_U16 addr, DEVADD *devadd );
*-----------------------------------------------------------------------------
* Function    : DEVADDn register is set by specified value
*             : 
*-----------------------------------------------------------------------------
* Argument    : USB_U16 addr             : Device address 
*             : DEVADD *devadd           : Set value
*-----------------------------------------------------------------------------
* Global In   : 
*-----------------------------------------------------------------------------
* Global Out  : 
*-----------------------------------------------------------------------------
* ReturnValue : void
*-----------------------------------------------------------------------------
* Note        : 
*""FUNC COMMENT END""********************************************************/
void usb_set_devadd( USB_U16 addr, DEVADD *devadd )
{
	DEVADD *ptr;

	switch( addr ) {
	case	DEVICE_0:
		ptr = (DEVADD *)&USB.DEVADD0.WORD;
		break;
	case	DEVICE_1:
		ptr = (DEVADD *)&USB.DEVADD1.WORD;
		break;
	case	DEVICE_2:
		ptr = (DEVADD *)&USB.DEVADD2.WORD;
		break;
	case	DEVICE_3:
		ptr = (DEVADD *)&USB.DEVADD3.WORD;
		break;
	case	DEVICE_4:
		ptr = (DEVADD *)&USB.DEVADD4.WORD;
		break;
	case	DEVICE_5:
		ptr = (DEVADD *)&USB.DEVADD5.WORD;
		break;
	case	DEVICE_6:
		ptr = (DEVADD *)&USB.DEVADD6.WORD;
		break;
	case	DEVICE_7:
		ptr = (DEVADD *)&USB.DEVADD7.WORD;
		break;
	case	DEVICE_8:
		ptr = (DEVADD *)&USB.DEVADD8.WORD;
		break;
	case	DEVICE_9:
		ptr = (DEVADD *)&USB.DEVADD9.WORD;
		break;
	case	DEVICE_10:
		ptr = (DEVADD *)&USB.DEVADDA.WORD;
		break;
	default:
		return;
		break;
	}
	ptr->WORD = (USB_U16)(devadd->WORD & 0x7fc0);
}

/*""FUNC COMMENT""*************************************************************
* ID          : 
* Outline     : DEVADDn register is obtained 
*-----------------------------------------------------------------------------
* Include     : 
*-----------------------------------------------------------------------------
* Declaration : void usb_get_devadd( USB_U16 addr, DEVADD *devadd );
*-----------------------------------------------------------------------------
* Function    : DEVADDn register is obtained 
*             : 
*-----------------------------------------------------------------------------
* Argument    : USB_U16 addr             : Device address 
*             : DEVADD *devadd           : DEVADD register value
*-----------------------------------------------------------------------------
* Global In   : 
*-----------------------------------------------------------------------------
* Global Out  : 
*-----------------------------------------------------------------------------
* ReturnValue : void
*-----------------------------------------------------------------------------
* Note        : 
*""FUNC COMMENT END""********************************************************/
void	usb_get_devadd( USB_U16 addr, DEVADD *devadd )
{
	DEVADD *ptr;

	switch( addr ) {
	case	DEVICE_0:
		ptr = (DEVADD *)&USB.DEVADD0.WORD;
		break;
	case	DEVICE_1:
		ptr = (DEVADD *)&USB.DEVADD1.WORD;
		break;
	case	DEVICE_2:
		ptr = (DEVADD *)&USB.DEVADD2.WORD;
		break;
	case	DEVICE_3:
		ptr = (DEVADD *)&USB.DEVADD3.WORD;
		break;
	case	DEVICE_4:
		ptr = (DEVADD *)&USB.DEVADD4.WORD;
		break;
	case	DEVICE_5:
		ptr = (DEVADD *)&USB.DEVADD5.WORD;
		break;
	case	DEVICE_6:
		ptr = (DEVADD *)&USB.DEVADD6.WORD;
		break;
	case	DEVICE_7:
		ptr = (DEVADD *)&USB.DEVADD7.WORD;
		break;
	case	DEVICE_8:
		ptr = (DEVADD *)&USB.DEVADD8.WORD;
		break;
	case	DEVICE_9:
		ptr = (DEVADD *)&USB.DEVADD9.WORD;
		break;
	case	DEVICE_10:
		ptr = (DEVADD *)&USB.DEVADDA.WORD;
		break;
	default:
		return;
		break;
	}
	*devadd = *ptr;
}

/*===========================================================================*/
/* End of File */
